@@ -19,6 +19,7 @@ from markdown_exec.formatters.bash import _format_bash
 from markdown_exec.formatters.console import _format_console
 from markdown_exec.formatters.markdown import _format_markdown
 from markdown_exec.formatters.pycon import _format_pycon
+from markdown_exec.formatters.pyodide import _format_pyodide
 from markdown_exec.formatters.python import _format_python
 from markdown_exec.formatters.sh import _format_sh
 from markdown_exec.formatters.tree import _format_tree
@@ -34,6 +35,7 @@ formatters = {
     "py": _format_python,
     "python": _format_python,
     "pycon": _format_pycon,
+    "pyodide": _format_pyodide,
     "sh": _format_sh,
     "tree": _format_tree,
 }
@@ -62,7 +64,7 @@ def validator(
         Success or not.
     """
     exec_value = _to_bool(inputs.pop("exec", "no"))
-    if language != "tree" and not exec_value:
+    if language not in {"tree", "pyodide"} and not exec_value:
         return False
     id_value = inputs.pop("id", "")
     id_prefix_value = inputs.pop("idprefix", None)
