@@ -3,15 +3,17 @@
 from __future__ import annotations
 
 from textwrap import indent
-from typing import Any, Callable
+from typing import TYPE_CHECKING, Any, Callable
 from uuid import uuid4
 
-from markdown.core import Markdown
 from markupsafe import Markup
 
 from markdown_exec.logger import get_logger
 from markdown_exec.rendering import MarkdownConverter, add_source, code_block
 
+if TYPE_CHECKING:
+    from markdown.core import Markdown
+
 logger = get_logger(__name__)
 default_tabs = ("Source", "Result")
 
@@ -29,7 +31,7 @@ class ExecutionError(Exception):
         self.returncode = returncode
 
 
-def _format_log_details(details: str, strip_fences: bool = False) -> str:
+def _format_log_details(details: str, *, strip_fences: bool = False) -> str:
     if strip_fences:
         lines = details.split("\n")
         if lines[0].startswith("```") and lines[-1].startswith("```"):
@@ -37,7 +39,7 @@ def _format_log_details(details: str, strip_fences: bool = False) -> str:
     return indent(details, " " * 2)
 
 
-def base_format(  # noqa: WPS231
+def base_format(
     *,
     language: str,
     run: Callable,
@@ -47,10 +49,12 @@ def base_format(  # noqa: WPS231
     source: str = "",
     result: str = "",
     tabs: tuple[str, str] = default_tabs,
-    id: str = "",  # noqa: A002,VNE003
+    id: str = "",  # noqa: A002
+    id_prefix: str | None = None,
     returncode: int = 0,
     transform_source: Callable[[str], tuple[str, str]] | None = None,
     session: str | None = None,
+    update_toc: bool = True,
     **options: Any,
 ) -> Markup:
     """Execute code and return HTML.
@@ -65,17 +69,20 @@ def base_format(  # noqa: WPS231
         result: If provided, use as language to format result in a code block.
         tabs: Titles of tabs (if used).
         id: An optional ID for the code block (useful when warning about errors).
+        id_prefix: A string used to prefix HTML ids in the generated HTML.
         returncode: The expected exit code.
         transform_source: An optional callable that returns transformed versions of the source.
             The input source is the one that is ran, the output source is the one that is
             rendered (when the source option is enabled).
         session: A session name, to persist state between executed code blocks.
+        update_toc: Whether to include generated headings
+            into the Markdown table of contents (toc extension).
         **options: Additional options passed from the formatter.
 
     Returns:
         HTML contents.
     """
-    markdown = MarkdownConverter(md)
+    markdown = MarkdownConverter(md, update_toc=update_toc)
     extra = options.get("extra", {})
 
     if transform_source:
@@ -85,7 +92,7 @@ def base_format(  # noqa: WPS231
         source_output = code
 
     try:
-        output = run(source_input, returncode=returncode, session=session, **extra)
+        output = run(source_input, returncode=returncode, session=session, id=id, **extra)
     except ExecutionError as error:
         identifier = id or extra.get("title", "")
         identifier = identifier and f"'{identifier}' "
@@ -102,7 +109,12 @@ def base_format(  # noqa: WPS231
         if source:
             placeholder = str(uuid4())
             wrapped_output = add_source(
-                source=source_output, location=source, output=placeholder, language=language, tabs=tabs, **extra
+                source=source_output,
+                location=source,
+                output=placeholder,
+                language=language,
+                tabs=tabs,
+                **extra,
             )
             return markdown.convert(wrapped_output, stash={placeholder: output})
         return Markup(output)
@@ -120,4 +132,5 @@ def base_format(  # noqa: WPS231
             result=result,
             **extra,
         )
-    return markdown.convert(wrapped_output)
+    prefix = id_prefix if id_prefix is not None else (f"{id}-" if id else None)
+    return markdown.convert(wrapped_output, id_prefix=prefix)
