@@ -17,10 +17,11 @@ def _run_bash(
     **extra: str,
 ) -> str:
     process = subprocess.run(
-        ["bash", "-c", code],
+        ["bash", "-c", code],  # noqa: S603,S607
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         text=True,
+        check=False,
     )
     if process.returncode != returncode:
         raise ExecutionError(code_block("sh", process.stdout, **extra), process.returncode)
