@@ -32,12 +32,12 @@ patch_loggers(get_logger)
 from __future__ import annotations
 
 import logging
-from typing import Any, Callable
+from typing import Any, Callable, ClassVar
 
 
 class _Logger:
     _default_logger: Any = logging.getLogger
-    _instances: dict[str, _Logger] = {}
+    _instances: ClassVar[dict[str, _Logger]] = {}
 
     def __init__(self, name: str) -> None:
         # default logger that can be patched by third-party
