@@ -8,6 +8,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, MutableMapping
 
 from mkdocs.config import config_options
+from mkdocs.config.base import Config
 from mkdocs.plugins import BasePlugin
 from mkdocs.utils import write_file
 
@@ -45,10 +46,20 @@ def _get_logger(name: str) -> _LoggerAdapter:
 patch_loggers(_get_logger)
 
 
-class MarkdownExecPlugin(BasePlugin):
-    """MkDocs plugin to easily enable custom fences for code blocks execution."""
+class MarkdownExecPluginConfig(Config):
+    """Configuration of the plugin (for `mkdocs.yml`)."""
 
-    config_scheme = (("languages", config_options.Type(list, default=list(formatters.keys()))),)
+    ansi = config_options.Choice(("auto", "off", "required", True, False), default="auto")
+    """Whether the `ansi` extra is required when installing the package."""
+    languages = config_options.ListOfItems(
+        config_options.Choice(formatters.keys()),
+        default=list(formatters.keys()),
+    )
+    """Which languages to enabled the extension for."""
+
+
+class MarkdownExecPlugin(BasePlugin[MarkdownExecPluginConfig]):
+    """MkDocs plugin to easily enable custom fences for code blocks execution."""
 
     def on_config(self, config: MkDocsConfig) -> MkDocsConfig | None:
         """Configure the plugin.
@@ -67,7 +78,7 @@ class MarkdownExecPlugin(BasePlugin):
         """
         self.mkdocs_config_dir = os.getenv("MKDOCS_CONFIG_DIR")
         os.environ["MKDOCS_CONFIG_DIR"] = os.path.dirname(config["config_file_path"])
-        self.languages = self.config["languages"]
+        self.languages = self.config.languages
         mdx_configs = config.setdefault("mdx_configs", {})
         superfences = mdx_configs.setdefault("pymdownx.superfences", {})
         custom_fences = superfences.setdefault("custom_fences", [])
@@ -80,7 +91,7 @@ class MarkdownExecPlugin(BasePlugin):
                     "format": formatter,
                 },
             )
-        markdown_config.save(config["markdown_extensions"], config["mdx_configs"])
+        markdown_config.save(config.markdown_extensions, config.mdx_configs)
         return config
 
     def on_env(  # noqa: D102
@@ -90,10 +101,11 @@ class MarkdownExecPlugin(BasePlugin):
         config: MkDocsConfig,
         files: Files,  # noqa: ARG002
     ) -> Environment | None:
-        css_filename = "assets/_markdown_exec_ansi.css"
-        css_content = Path(__file__).parent.joinpath("ansi.css").read_text()
-        write_file(css_content.encode("utf-8"), os.path.join(config["site_dir"], css_filename))
-        config["extra_css"].insert(0, css_filename)
+        if self.config.ansi in ("required", True) or (self.config.ansi == "auto" and ansi_ok):
+            self._add_css(config, "ansi.css")
+        if "pyodide" in self.languages:
+            self._add_css(config, "pyodide.css")
+            self._add_js(config, "pyodide.js")
         return env
 
     def on_post_build(self, *, config: MkDocsConfig) -> None:  # noqa: ARG002,D102
@@ -103,3 +115,15 @@ class MarkdownExecPlugin(BasePlugin):
             os.environ.pop("MKDOCS_CONFIG_DIR", None)
         else:
             os.environ["MKDOCS_CONFIG_DIR"] = self.mkdocs_config_dir
+
+    def _add_asset(self, config: MkDocsConfig, asset_file: str, asset_type: str) -> None:
+        asset_filename = f"assets/_markdown_exec_{asset_file}"
+        asset_content = Path(__file__).parent.joinpath(asset_file).read_text()
+        write_file(asset_content.encode("utf-8"), os.path.join(config.site_dir, asset_filename))
+        config[f"extra_{asset_type}"].insert(0, asset_filename)
+
+    def _add_css(self, config: MkDocsConfig, css_file: str) -> None:
+        self._add_asset(config, css_file, "css")
+
+    def _add_js(self, config: MkDocsConfig, js_file: str) -> None:
+        self._add_asset(config, js_file, "javascript")
